@@ -29,12 +29,14 @@ SCRIPTS_TARGET_PROPERTY = "dir_dist_scripts"
 
 use_plugin("core")
 
+
 @init
 def init_python_directories(project):
     project.set_property_if_unset(PYTHON_SOURCES_PROPERTY, "src/main/python")
     project.set_property_if_unset(SCRIPTS_SOURCES_PROPERTY, "src/main/scripts")
     project.set_property_if_unset(SCRIPTS_TARGET_PROPERTY, None)
-    project.set_property_if_unset(DISTRIBUTION_PROPERTY, "$dir_target/dist/{0}-{1}".format(project.name, project.version))
+    project.set_property_if_unset(DISTRIBUTION_PROPERTY,
+                                  "$dir_target/dist/{0}-{1}".format(project.name, project.version))
 
     def list_packages():
         source_path = project.expand_path("$dir_source_main_python")
@@ -58,6 +60,7 @@ def init_python_directories(project):
 
     project.list_scripts = list_scripts
 
+
 @task
 @description("Package a python application.")
 def package(project, logger):
@@ -68,6 +71,7 @@ def package(project, logger):
     copy_python_sources(project, logger)
     copy_scripts(project, logger)
 
+
 def copy_scripts(project, logger):
     scripts_target = project.expand_path("$" + DISTRIBUTION_PROPERTY)
     if project.get_property(SCRIPTS_TARGET_PROPERTY):
@@ -86,6 +90,7 @@ def copy_scripts(project, logger):
         source_file = project.expand_path("$" + SCRIPTS_SOURCES_PROPERTY, script)
         shutil.copy(source_file, scripts_target)
 
+
 def copy_python_sources(project, logger):
     for package in os.listdir(project.expand_path("$" + PYTHON_SOURCES_PROPERTY)):
         if HIDDEN_FILE_NAME_PATTERN.match(package):
@@ -100,6 +105,7 @@ def copy_python_sources(project, logger):
         else:
             shutil.copyfile(source, target)
 
+
 def init_dist_target(project, logger):
     dist_target = project.expand_path("$" + DISTRIBUTION_PROPERTY)
 
