@@ -31,6 +31,7 @@ from pybuilder.plugins.python.python_plugin_helper import execute_tool_on_source
 
 use_plugin("python.core")
 
+
 @init
 def initialize_flake8_plugin(project):
     project.build_depends_on("flake8")
@@ -39,7 +40,11 @@ def initialize_flake8_plugin(project):
         project.set_property("flake8_verbose_output", True)
     else:
         project.set_property("flake8_verbose_output", False)
+
     project.set_property("flake8_break_build", False)
+    project.set_property("flake8_max_line_length", 120)
+    project.set_property("flake8_exclude_patterns", None)
+
 
 @after("prepare")
 def assert_flake8_is_executable(logger):
@@ -67,6 +72,13 @@ def analyze(project, logger):
         ignore_option = "--ignore={0}".format(property_flake8_ignore)
         command_and_arguments.append(ignore_option)
 
+    max_line_length = project.get_property("flake8_max_line_length")
+    command_and_arguments.append("--max-line-length={0}".format(max_line_length))
+
+    exclude_patterns = project.get_property("flake8_exclude_patterns")
+    if exclude_patterns:
+        command_and_arguments.append("--exclude={0}".format(exclude_patterns))
+
     execution_result = execute_tool_on_source_files(project=project,
                                                     name="flake8",
                                                     command_and_arguments=command_and_arguments,
